/* ====================================================================
 * Copyright (c) 2007 Open Source Applications Foundation.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions: 
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 * ====================================================================
 */

package org.osafoundation.text;

import java.text.BreakIterator;
import java.text.CharacterIterator;

/**
 * @author Andi Vajda
 */

public class PythonBreakIterator extends BreakIterator {

    protected long pythonBreakIterator;

    public PythonBreakIterator(long pythonBreakIterator)
    {
        this.pythonBreakIterator = pythonBreakIterator;
        incRef();
    }

    protected void finalize()
        throws Throwable
    {
        decRef();
    }

    protected native void incRef();
    protected native void decRef();

    public native boolean isBoundary(int offset);
    public native int current();
    public native int first();
    public native int following(int offset);
    public native int preceding(int offset);
    public native int last();
    public native int next();
    public native int previous();
    public native void setText(String text);

    public int next(int n)
    {
        int boundary = n;

        if (n > 0)
            for (; n > 0; n -= 1)
                boundary = next();
        else if (n < 0)
            for (; n < 0; n += 1)
                boundary = previous();

        return boundary;
    }

    /* not implemented */
    public native void setText(CharacterIterator iterator);
    public native CharacterIterator getText();
}
